@@ -1,6 +1,6 @@
-.onLoad <- function(lib, pkg) {
-	require(methods)
-}
+#.onLoad <- function(lib, pkg) {
+#	require(methods)
+#}
 
 .onUnload <- function(libpath)
     library.dynam.unload("sp", libpath)
